@@ -87,7 +87,8 @@ private:
 	std::string tag;
 
 	Matcher matcher;
-	bool apply_filter;
+	bool filter_active;
+	void apply_filter(const std::string& filter_query);
 
 	History filterhistory;
 
@@ -96,7 +97,7 @@ private:
 
 	RegexManager& rxman;
 
-	FilterContainer& filters;
+	FilterContainer& filter_container;
 
 	nonstd::optional<FeedSortStrategy> old_sort_strategy;
 
