@@ -5,6 +5,7 @@
 
 #include "3rd-party/optional.hpp"
 
+#include "configcontainer.h"
 #include "fmtstrformatter.h"
 #include "history.h"
 #include "listformaction.h"
@@ -14,6 +15,8 @@
 
 namespace newsboat {
 
+class RssItem;
+
 typedef std::pair<std::shared_ptr<RssItem>, unsigned int> ItemPtrPosPair;
 
 enum class InvalidationMode { NONE, PARTIAL, COMPLETE };
@@ -91,8 +94,8 @@ protected:
 	std::shared_ptr<RssFeed> feed;
 
 	Matcher matcher;
-
-	bool apply_filter;
+	bool filter_active;
+	void apply_filter(const std::string& filter_query);
 
 private:
 	void register_format_styles();
@@ -155,7 +158,7 @@ private:
 
 	ListFormatter listfmt;
 	Cache* rsscache;
-	FilterContainer& filters;
+	FilterContainer& filter_container;
 };
 
 } // namespace newsboat
