@@ -89,7 +89,8 @@ public:
 		const std::vector<FilterNameExprPair>& filters);
 
 	nonstd::optional<std::uint8_t> open_in_browser(const std::string& url,
-		const std::string& feedurl, const std::string& type, bool interactive);
+		const std::string& feedurl, const std::string& type, const std::string& title,
+		bool interactive);
 	void open_in_pager(const std::string& filename);
 
 	std::string get_filename_suggestion(const std::string& s);
@@ -179,6 +180,9 @@ protected:
 	FilterContainer& filters;
 	const ColorManager& colorman;
 	std::vector<std::string> suggestions;
+
+private:
+	bool try_prepare_query_feed(std::shared_ptr<RssFeed> feed);
 };
 
 } // namespace newsboat
