@@ -255,23 +255,15 @@ bool InoreaderApi::update_article_flags(const std::string& inoflags,
 	bool success = true;
 
 	if (star_flag.length() > 0) {
-		if (strchr(inoflags.c_str(), star_flag[0]) == nullptr &&
-			strchr(newflags.c_str(), star_flag[0]) != nullptr) {
-			success = star_article(guid, true);
-		} else if (strchr(inoflags.c_str(), star_flag[0]) != nullptr &&
-			strchr(newflags.c_str(), star_flag[0]) == nullptr) {
-			success = star_article(guid, false);
-		}
+		update_flag(inoflags, newflags, star_flag[0], [&](bool added) {
+			success = star_article(guid, added);
+		});
 	}
 
 	if (share_flag.length() > 0) {
-		if (strchr(inoflags.c_str(), share_flag[0]) == nullptr &&
-			strchr(newflags.c_str(), share_flag[0]) != nullptr) {
-			success = share_article(guid, true);
-		} else if (strchr(inoflags.c_str(), share_flag[0]) != nullptr &&
-			strchr(newflags.c_str(), share_flag[0]) == nullptr) {
-			success = share_article(guid, false);
-		}
+		update_flag(inoflags, newflags, share_flag[0], [&](bool added) {
+			success = share_article(guid, added);
+		});
 	}
 
 	return success;
