@@ -747,6 +747,20 @@ bool ItemListFormAction::process_operation(Operation op,
 			return false;
 		}
 		break;
+	case OP_ARTICLEFEED: {
+		auto feeds = v->get_ctrl()->get_feedcontainer()->get_all_feeds();
+		size_t pos;
+		auto article_feed = visible_items[itempos].first->get_feedptr();
+		for (pos = 0; pos < feeds.size(); pos++) {
+			if (feeds[pos] == article_feed) {
+				break;
+			}
+		}
+		if (pos != feeds.size()) {
+			v->push_itemlist(pos);
+		}
+	}
+	break;
 	default:
 		ListFormAction::process_operation(op, automatic, args);
 		break;
@@ -772,7 +786,8 @@ bool ItemListFormAction::open_position_in_browser(
 		const auto item = visible_items[pos].first;
 		const auto link = item->link();
 		const auto feedurl = item->feedurl();
-		const auto exit_code = v->open_in_browser(link, feedurl, "article", interactive);
+		const auto exit_code = v->open_in_browser(link, feedurl, "article", item->title(),
+				interactive);
 		if (!exit_code.has_value()) {
 			v->get_statusline().show_error(_("Failed to spawn browser"));
 			return false;
