@@ -368,7 +368,8 @@ void View::open_in_pager(const std::string& filename)
 }
 
 nonstd::optional<std::uint8_t> View::open_in_browser(const std::string& url,
-	const std::string& feedurl, const std::string& type, bool interactive)
+	const std::string& feedurl, const std::string& type, const std::string& title,
+	bool interactive)
 {
 	std::string cmdline;
 	const std::string browser = cfg->get_configvalue("browser");
@@ -376,14 +377,17 @@ nonstd::optional<std::uint8_t> View::open_in_browser(const std::string& url,
 	const std::string escaped_feedurl = "'" + utils::replace_all(feedurl, "'",
 			"%27") + "'";
 	const std::string quoted_type = "'" + type + "'";
+	const std::string escaped_title = utils::preserve_quotes(title);
 
 	if (browser.find("%u") != std::string::npos
 		|| browser.find("%F") != std::string::npos
-		|| browser.find("%t") != std::string::npos) {
+		|| browser.find("%t") != std::string::npos
+		|| browser.find("%T") != std::string::npos) {
 		cmdline = utils::replace_all(browser, {
 			{"%u", escaped_url},
 			{"%F", escaped_feedurl},
-			{"%t", quoted_type}
+			{"%t", quoted_type},
+			{"%T", escaped_title}
 		});
 	} else {
 		if (browser != "") {
@@ -481,11 +485,7 @@ std::shared_ptr<ItemListFormAction> View::push_itemlist(
 
 	feed->purge_deleted_items();
 
-	try {
-		prepare_query_feed(feed);
-	} catch (const MatcherException& e) {
-		const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-		status_line.show_error(msg);
+	if (!try_prepare_query_feed(feed)) {
 		return nullptr;
 	}
 
@@ -732,11 +732,7 @@ bool View::get_random_unread(ItemListFormAction& itemlist,
 		LOG(Level::DEBUG,
 			"View::get_random_unread: found feed with unread "
 			"articles");
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -779,11 +775,7 @@ bool View::get_previous_unread(ItemListFormAction& itemlist,
 		LOG(Level::DEBUG,
 			"View::get_previous_unread: found feed with unread "
 			"articles");
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -805,11 +797,7 @@ bool View::get_next_unread_feed(ItemListFormAction& itemlist)
 {
 	unsigned int feedpos;
 	if (feedlist_form->jump_to_next_unread_feed(feedpos)) {
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -824,11 +812,7 @@ bool View::get_prev_unread_feed(ItemListFormAction& itemlist)
 {
 	unsigned int feedpos;
 	if (feedlist_form->jump_to_previous_unread_feed(feedpos)) {
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -862,11 +846,7 @@ bool View::get_next_unread(ItemListFormAction& itemlist,
 		LOG(Level::DEBUG,
 			"View::get_next_unread: found feed with unread "
 			"articles");
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -901,11 +881,7 @@ bool View::get_previous(ItemListFormAction& itemlist,
 		status_line.show_error(_("Already on first item."));
 	} else if (feedlist_form->jump_to_previous_feed(feedpos)) {
 		LOG(Level::DEBUG, "View::get_previous: previous feed");
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -939,11 +915,7 @@ bool View::get_next(ItemListFormAction& itemlist, ItemViewFormAction* itemview)
 		status_line.show_error(_("Already on last item."));
 	} else if (feedlist_form->jump_to_next_feed(feedpos)) {
 		LOG(Level::DEBUG, "View::get_next: next feed");
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -965,11 +937,7 @@ bool View::get_next_feed(ItemListFormAction& itemlist)
 {
 	unsigned int feedpos;
 	if (feedlist_form->jump_to_next_feed(feedpos)) {
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -984,11 +952,7 @@ bool View::get_prev_feed(ItemListFormAction& itemlist)
 {
 	unsigned int feedpos;
 	if (feedlist_form->jump_to_previous_feed(feedpos)) {
-		try {
-			prepare_query_feed(feedlist_form->get_feed());
-		} catch (const MatcherException& e) {
-			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
-			status_line.show_error(msg);
+		if (!try_prepare_query_feed(feedlist_form->get_feed())) {
 			return false;
 		}
 		itemlist.set_feed(feedlist_form->get_feed());
@@ -1014,6 +978,18 @@ void View::prepare_query_feed(std::shared_ptr<RssFeed> feed)
 	}
 }
 
+bool View::try_prepare_query_feed(std::shared_ptr<RssFeed> feed)
+{
+	try {
+		prepare_query_feed(feed);
+		return true;
+	} catch (const MatcherException& e) {
+		const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+		status_line.show_error(msg);
+		return false;
+	}
+}
+
 void View::force_redraw()
 {
 	std::shared_ptr<FormAction> fa = get_current_formaction();
